@@ -1,6 +1,6 @@
 package Crypt::PBKDF2; 
 # ABSTRACT: The PBKDF2 password hashing algorithm.
-our $VERSION = '0.160410'; # VERSION
+our $VERSION = '0.161520'; # VERSION
 our $AUTHORITY = 'cpan:ARODLAND'; # AUTHORITY
 use Moo 2;
 use strictures 2;
@@ -10,7 +10,7 @@ use Carp qw(croak);
 use Module::Runtime;
 use Try::Tiny;
 use Type::Tiny;
-use Types::Standard qw(Str Int HashRef ConsumerOf);
+use Types::Standard 1.000005 qw(Str Int HashRef ConsumerOf);
 use Scalar::Util qw(blessed);
 
 sub BUILD {
@@ -364,7 +364,7 @@ Crypt::PBKDF2 - The PBKDF2 password hashing algorithm.
 
 =head1 VERSION
 
-version 0.160410
+version 0.161520
 
 =head1 SYNOPSIS
 
